@@ -29,7 +29,6 @@
 #include <QBuffer>
 #include <QColor>
 #include <QFile>
-#include <QImage>
 #include <QJsonArray>
 #include <QJsonDocument>
 #include <QJsonObject>
@@ -369,6 +368,21 @@ QImage Pass::logo(unsigned int devicePixelRatio) const
     return image(QStringLiteral("logo"), devicePixelRatio);
 }
 
+QImage Pass::strip(unsigned int devicePixelRatio) const
+{
+    return image(QStringLiteral("strip"), devicePixelRatio);
+}
+
+QImage Pass::background(unsigned int devicePixelRatio) const
+{
+    return image(QStringLiteral("background"), devicePixelRatio);
+}
+
+QImage KPkPass::Pass::footer(unsigned int devicePixelRatio) const
+{
+    return image(QStringLiteral("footer"), devicePixelRatio);
+}
+
 QString Pass::authenticationToken() const
 {
     return d->passObj.value(QLatin1String("authenticationToken")).toString();
